@@ -14,10 +14,10 @@ def user_agents(cur):
                     FROM
                         user_agents)
             """
-
     cur.execute(sql)
     return cur.fetchall()
 
-def choose_random(user_agents):
-    return choices(population=[ua['user_agent'] for ua in user_agents],
-                    weights=[ua['percent'] for ua in user_agents])[0]
\ No newline at end of file
+def random_uas(cur, count):
+    uas = user_agents(cur)
+    return choices(population=[ua['user_agent'] for ua in uas],
+                    weights=[ua['percent'] for ua in uas], k=count)
\ No newline at end of file
